@@ -23,11 +23,10 @@
 #include "config.h"
 #endif
 
-#include <gnome.h>
+#include <glib/gi18n.h>
 #include <string.h>
 
 #include "button.h"
-#include "stock.h"
 #include "track.h"
 #include "volume.h"
 
@@ -35,18 +34,18 @@ static const struct {
   gchar *label,
 	*pixmap;
 } pix[] = {
-  { "cd",         GTK_STOCK_CDROM                       },
-  { "line",       GNOME_STOCK_LINE_IN                   },
-  { "mic",        GNOME_STOCK_MIC                       },
-  { "mix",        GNOME_VOLUME_CONTROL_STOCK_MIXER      },
-  { "pcm",        GNOME_VOLUME_CONTROL_STOCK_TONE       },
-  { "headphone",  GNOME_VOLUME_CONTROL_STOCK_HEADPHONES },
-  { "phone",      GNOME_VOLUME_CONTROL_STOCK_PHONE      },
-  { "speaker",    GNOME_STOCK_VOLUME                    },
-  { "video",      GNOME_VOLUME_CONTROL_STOCK_VIDEO      },
-  { "volume",     GNOME_VOLUME_CONTROL_STOCK_TONE       },
-  { "master",     GNOME_VOLUME_CONTROL_STOCK_TONE       },
-  { "3d",         GNOME_VOLUME_CONTROL_STOCK_3DSOUND    },
+  { "cd",         "media-cdrom"         	},
+  { "line",       "gvc-line-in"                 },
+  { "mic",        "audio-input-microphone"      },
+  { "mix",        "multimedia-volume-control"   },
+  { "pcm",        "gvc-tone"       		},
+  { "headphone",  "gvc-headphones" 		},
+  { "phone",      "phone"      			},
+  { "speaker",    "audio-volume-high"           },
+  { "video",      "video-display"      		},
+  { "volume",     "gvc-tone"       		},
+  { "master",     "gvc-tone"       		},
+  { "3d",         "gvc-3d-sound"		},
   { NULL, NULL }
 };
 
@@ -83,7 +82,7 @@ should_toggle_record_switch (const GstMixerTrack *track)
 {
   return GST_MIXER_TRACK_HAS_FLAG (track, GST_MIXER_TRACK_INPUT);
 }
- 
+
 
 static void
 cb_toggle_changed (GtkToggleButton *button,
@@ -117,32 +116,35 @@ cb_option_changed (GtkComboBox *box,
  * Timeout to check for changes in mixer outside ourselves.
  */
 
-static gboolean
-cb_check (gpointer data)
+void
+gnome_volume_control_track_update (GnomeVolumeControlTrack *trkw)
 {
-  GnomeVolumeControlTrack *trkw = data;
   gboolean mute, record;
   gboolean vol_is_zero = FALSE, slider_is_zero = FALSE;
 
+  g_return_if_fail (trkw != NULL);
+
   /* trigger an update of the mixer state */
   if (!GST_IS_MIXER_OPTIONS (trkw->track)) {
     gint *dummy = g_new (gint, MAX (trkw->track->num_channels, 1));
     gst_mixer_get_volume (trkw->mixer, trkw->track, dummy);
     g_free (dummy);
   }
-  
+
   mute = GST_MIXER_TRACK_HAS_FLAG (trkw->track,
 				GST_MIXER_TRACK_MUTE) ? TRUE : FALSE;
   record = GST_MIXER_TRACK_HAS_FLAG (trkw->track,
 				GST_MIXER_TRACK_RECORD) ? TRUE : FALSE;
 
   if (trkw->sliderbox) {
+    gnome_volume_control_volume_update (GNOME_VOLUME_CONTROL_VOLUME (trkw->sliderbox));
     gnome_volume_control_volume_ask (
       GNOME_VOLUME_CONTROL_VOLUME (trkw->sliderbox),
       &vol_is_zero, &slider_is_zero);
   }
+
   if (!slider_is_zero && vol_is_zero)
-    mute = TRUE;
+    mute |= TRUE;
 
   if (trkw->mute) {
     if (gnome_volume_control_button_get_active (trkw->mute) == mute) {
@@ -169,6 +171,13 @@ cb_check (gpointer data)
   /* FIXME:
    * - options.
    */
+}
+
+
+static gboolean
+cb_check (gpointer data)
+{
+  gnome_volume_control_track_update (data);
 
   return TRUE;
 }
@@ -190,6 +199,10 @@ gnome_volume_control_track_add_title (GtkTable *table,
   gchar *ulabel = NULL;
   gchar *str = NULL;
   gint i;
+  gboolean need_timeout = TRUE;
+
+  need_timeout = ((gst_mixer_get_mixer_flags (GST_MIXER (mixer)) &
+		   GST_MIXER_FLAG_AUTO_NOTIFICATIONS) == 0);
 
   /* start */
   ctrl = g_new0 (GnomeVolumeControlTrack, 1);
@@ -201,7 +214,8 @@ gnome_volume_control_track_add_title (GtkTable *table,
   ctrl->visible = TRUE;
   ctrl->table = table;
   ctrl->pos = tab_pos;
-  ctrl->id = g_timeout_add (200, cb_check, ctrl);
+  if (need_timeout)
+    ctrl->id = g_timeout_add (200, cb_check, ctrl);
 
   /* find image from label string (optional) */
   if (g_object_class_find_property (G_OBJECT_GET_CLASS (track), "untranslated-label"))
@@ -228,7 +242,7 @@ gnome_volume_control_track_add_title (GtkTable *table,
   }
 
   if (str != NULL) {
-    if ((ctrl->image = gtk_image_new_from_stock (str, GTK_ICON_SIZE_MENU)) != NULL) {
+    if ((ctrl->image = gtk_image_new_from_icon_name (str, GTK_ICON_SIZE_MENU)) != NULL) {
       gtk_misc_set_alignment (GTK_MISC (ctrl->image), 0.5, 0.5);
       if (or == GTK_ORIENTATION_VERTICAL) {
         gtk_table_attach (GTK_TABLE (table), ctrl->image,
@@ -270,8 +284,7 @@ gnome_volume_control_track_add_title (GtkTable *table,
 static void
 gnome_volume_control_track_put_switch (GtkTable *table,
 				       gint      tab_pos,
-				       GnomeVolumeControlTrack *ctrl,
-				       GnomeAppBar *appbar)
+				       GnomeVolumeControlTrack *ctrl)
 {
   GtkWidget *button;
   AtkObject *accessible;
@@ -286,9 +299,9 @@ gnome_volume_control_track_put_switch (GtkTable *table,
 
   /* mute button */
   msg = g_strdup_printf (_("Mute/unmute %s"), ctrl->track->label);
-  button = gnome_volume_control_button_new (GNOME_VOLUME_CONTROL_STOCK_PLAY,
-					    GNOME_VOLUME_CONTROL_STOCK_NOPLAY,
-					    appbar, msg);
+  button = gnome_volume_control_button_new ("audio-volume-high",
+					    "audio-volume-muted",
+					     msg);
   ctrl->mute = GNOME_VOLUME_CONTROL_BUTTON (button);
   g_free (msg);
   gnome_volume_control_button_set_active (GNOME_VOLUME_CONTROL_BUTTON (button),
@@ -318,8 +331,7 @@ gnome_volume_control_track_add_playback	(GtkTable *table,
 					 GstMixer *mixer,
 					 GstMixerTrack *track,
 					 GtkWidget *l_sep,
-					 GtkWidget *r_sep,
-					 GnomeAppBar *appbar)
+					 GtkWidget *r_sep)
 {
   GnomeVolumeControlTrack *ctrl;
   GtkWidget *slider;
@@ -335,20 +347,19 @@ gnome_volume_control_track_add_playback	(GtkTable *table,
 
   /* switch exception (no sliders) */
   if (track->num_channels == 0) {
-    gnome_volume_control_track_put_switch (table, tab_pos, ctrl, appbar);
+    gnome_volume_control_track_put_switch (table, tab_pos, ctrl);
     return ctrl;
   }
 
   ctrl->sliderbox = gnome_volume_control_volume_new (ctrl->mixer,
-						     ctrl->track, 6,
-						     appbar);
+						     ctrl->track, 6);
   gtk_table_attach (GTK_TABLE (table), ctrl->sliderbox,
 		    tab_pos, tab_pos + 1, 2, 3,
 		    GTK_EXPAND, GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_widget_show (ctrl->sliderbox);
 
   /* mute button */
-  gnome_volume_control_track_put_switch (table, tab_pos, ctrl, appbar);
+  gnome_volume_control_track_put_switch (table, tab_pos, ctrl);
 
   return ctrl;
 }
@@ -359,8 +370,7 @@ gnome_volume_control_track_add_recording (GtkTable *table,
 					  GstMixer *mixer,
 					  GstMixerTrack *track,
 					  GtkWidget *l_sep,
-					  GtkWidget *r_sep,
-					  GnomeAppBar *appbar)
+					  GtkWidget *r_sep)
 {
   GnomeVolumeControlTrack *ctrl;
   GtkWidget *button;
@@ -368,22 +378,18 @@ gnome_volume_control_track_add_recording (GtkTable *table,
   gchar *accessible_name, *msg;
 
   ctrl = gnome_volume_control_track_add_playback (table, tab_pos, mixer,
-						  track, l_sep, r_sep,
-						  appbar);
+						  track, l_sep, r_sep);
   if (track->num_channels == 0) {
     return ctrl;
   }
 
+  /* only the record button here */
+  msg = g_strdup_printf (_("Toggle audio recording from %s"), ctrl->track->label);
   /* FIXME:
    * - there's something fishy about this button, it
    *     is always FALSE.
    */
-
-  /* only the record button here */
-  msg = g_strdup_printf (_("Toggle audio recording from %s"), ctrl->track->label);
-  button = gnome_volume_control_button_new (GNOME_VOLUME_CONTROL_STOCK_RECORD,
-					    GNOME_VOLUME_CONTROL_STOCK_NORECORD,
-					    appbar, msg);
+  button = gnome_volume_control_button_new ("audio-input-microphone", "audio-input-microphone-muted", msg);
   ctrl->record = GNOME_VOLUME_CONTROL_BUTTON (button);
   g_free (msg);
   gnome_volume_control_button_set_active (GNOME_VOLUME_CONTROL_BUTTON (button),
@@ -415,8 +421,7 @@ gnome_volume_control_track_add_switch (GtkTable *table,
 				       GstMixer *mixer,
 				       GstMixerTrack *track,
 				       GtkWidget *l_sep,
-				       GtkWidget *r_sep,
-				       GnomeAppBar *appbar)
+				       GtkWidget *r_sep)
 {
   GnomeVolumeControlTrack *ctrl;
 
@@ -440,8 +445,8 @@ gnome_volume_control_track_add_switch (GtkTable *table,
   g_signal_connect (ctrl->toggle, "toggled",
 		    G_CALLBACK (cb_toggle_changed), ctrl);
   gtk_widget_show (ctrl->toggle);
-                                                                                
-  return ctrl;  
+
+  return ctrl;
 }
 
 GnomeVolumeControlTrack *
@@ -450,12 +455,11 @@ gnome_volume_control_track_add_option (GtkTable *table,
 				       GstMixer *mixer,
 				       GstMixerTrack *track,
 				       GtkWidget *l_sep,
-				       GtkWidget *r_sep,
-				       GnomeAppBar *appbar)
+				       GtkWidget *r_sep)
 {
   GnomeVolumeControlTrack *ctrl;
   GstMixerOptions *options = GST_MIXER_OPTIONS (track);
-  const GList *opt;
+  const GList *opt, *opts;
   AtkObject *accessible;
   gchar *accessible_name;
   gint i = 0;
@@ -467,11 +471,18 @@ gnome_volume_control_track_add_option (GtkTable *table,
 
   /* optionmenu */
   active_opt = gst_mixer_get_option (mixer, GST_MIXER_OPTIONS (track));
-  ctrl->options = gtk_combo_box_new_text ();
-  for (opt = options->values; opt != NULL; opt = opt->next, i++) {
-    gtk_combo_box_append_text (GTK_COMBO_BOX (ctrl->options), opt->data);
-    if (!strcmp (active_opt, opt->data)) {
-      gtk_combo_box_set_active (GTK_COMBO_BOX (ctrl->options), i);
+  if (active_opt != NULL) {
+    ctrl->options = gtk_combo_box_new_text ();
+    opts = gst_mixer_options_get_values (options);
+    for (opt = opts; opt != NULL; opt = opt->next, i++) {
+      if (opt->data == NULL)
+	continue;
+
+      gtk_combo_box_append_text (GTK_COMBO_BOX (ctrl->options), opt->data);
+
+      if (g_str_equal (active_opt, opt->data)) {
+	gtk_combo_box_set_active (GTK_COMBO_BOX (ctrl->options), i);
+      }
     }
   }
 
